@@ -249,6 +249,28 @@ sub setup_test_apps {
         $mapped;
     };
 
+    $app{'psgix.input.non-buffered.cookie_options'} = builder {
+        if ($ENV{PLACK_DEBUG}) {
+            use Log::Dispatch;
+            my $logger = Log::Dispatch->new(
+                outputs => [
+                    [
+                        'Screen',
+                        min_level => 'debug',
+                        stderr    => 1,
+                        newline   => 1
+                    ]
+                ],
+            );
+            enable "LogDispatch", logger => $logger;
+        }
+        enable 'XSRFBlock',
+            header_name => 'X-XSRF-Token',
+            meta_tag => 'my_xsrf_meta_tag',
+            cookie_options => { secure => 1, httponly => 1 };
+        $mapped;
+    };
+
 
     return \%app;
 }
